@@ -449,18 +449,17 @@ class DataType:
     def _is_logical_type(self) -> builtins.bool:
         return self._dtype.is_logical()
 
+    def _is_temporal_type(self) -> builtins.bool:
+        return self._dtype.is_temporal()
+
     def __repr__(self) -> str:
         return self._dtype.__repr__()
 
     def __eq__(self, other: object) -> builtins.bool:
         return isinstance(other, DataType) and self._dtype.is_equal(other._dtype)
 
-    def __getstate__(self) -> bytes:
-        return self._dtype.__getstate__()
-
-    def __setstate__(self, state: bytes) -> None:
-        self._dtype = PyDataType.__new__(PyDataType)
-        self._dtype.__setstate__(state)
+    def __reduce__(self) -> tuple:
+        return DataType._from_pydatatype, (self._dtype,)
 
     def __hash__(self) -> int:
         return self._dtype.__hash__()
