@@ -134,24 +134,22 @@ class Schema:
 
         return Schema._from_pyschema(self._schema.union(other._schema))
 
-    def __getstate__(self) -> bytes:
-        return self._schema.__getstate__()
-
-    def __setstate__(self, state: bytes) -> None:
-        self._schema = _PySchema.__new__(_PySchema)
-        self._schema.__setstate__(state)
+    def __reduce__(self) -> tuple:
+        return Schema._from_pyschema, (self._schema,)
 
     @classmethod
     def from_parquet(
         cls,
         path: str,
         io_config: IOConfig | None = None,
+        multithreaded_io: bool | None = None,
         coerce_int96_timestamp_unit: TimeUnit = TimeUnit.ns(),
     ) -> Schema:
         return Schema._from_pyschema(
             _read_parquet_schema(
                 uri=path,
                 io_config=io_config,
+                multithreaded_io=multithreaded_io,
                 coerce_int96_timestamp_unit=coerce_int96_timestamp_unit._timeunit,
             )
         )
