@@ -1,9 +1,7 @@
 from __future__ import annotations
 
 from abc import abstractmethod
-from typing import TypeVar
-
-import fsspec
+from typing import TYPE_CHECKING, TypeVar
 
 from daft.daft import (
     CsvSourceConfig,
@@ -12,12 +10,15 @@ from daft.daft import (
     FileInfos,
     JsonSourceConfig,
     ParquetSourceConfig,
+    StorageConfig,
 )
-from daft.filesystem import get_filesystem_from_path
 from daft.logical.schema import Schema
 from daft.runners.partitioning import TableParseCSVOptions
 from daft.table import schema_inference
 
+if TYPE_CHECKING:
+    import fsspec
+
 PartitionT = TypeVar("PartitionT")
 
 
@@ -33,6 +34,7 @@ class RunnerIO:
         source_path: list[str],
         file_format_config: FileFormatConfig | None = None,
         fs: fsspec.AbstractFileSystem | None = None,
+        storage_config: StorageConfig | None = None,
     ) -> FileInfos:
         """Globs the specified filepath to construct a FileInfos object containing file and dir metadata.
 
@@ -47,9 +49,9 @@ class RunnerIO:
     @abstractmethod
     def get_schema_from_first_filepath(
         self,
-        file_info: FileInfos,
+        file_infos: FileInfos,
         file_format_config: FileFormatConfig,
-        fs: fsspec.AbstractFileSystem | None,
+        storage_config: StorageConfig,
     ) -> Schema:
         raise NotImplementedError()
 
@@ -57,19 +59,16 @@ class RunnerIO:
 def sample_schema(
     filepath: str,
     file_format_config: FileFormatConfig,
-    fs: fsspec.AbstractFileSystem | None,
+    storage_config: StorageConfig,
 ) -> Schema:
     """Helper method that samples a schema from the specified source"""
-    if fs is None:
-        fs = get_filesystem_from_path(filepath)
-
     file_format = file_format_config.file_format()
     config = file_format_config.config
     if file_format == FileFormat.Csv:
         assert isinstance(config, CsvSourceConfig)
         return schema_inference.from_csv(
             file=filepath,
-            fs=fs,
+            storage_config=storage_config,
             csv_options=TableParseCSVOptions(
                 delimiter=config.delimiter,
                 header_index=0 if config.has_headers else None,
@@ -79,15 +78,13 @@ def sample_schema(
         assert isinstance(config, JsonSourceConfig)
         return schema_inference.from_json(
             file=filepath,
-            fs=fs,
+            storage_config=storage_config,
         )
     elif file_format == FileFormat.Parquet:
         assert isinstance(config, ParquetSourceConfig)
         return schema_inference.from_parquet(
             file=filepath,
-            fs=fs,
-            io_config=config.io_config,
-            use_native_downloader=config.use_native_downloader,
+            storage_config=storage_config,
         )
     else:
         raise NotImplementedError(f"Schema inference for {file_format} not implemented")
