@@ -12,6 +12,7 @@ from daft.daft import PyTable as _PyTable
 from daft.daft import read_parquet as _read_parquet
 from daft.daft import read_parquet_bulk as _read_parquet_bulk
 from daft.daft import read_parquet_into_pyarrow as _read_parquet_into_pyarrow
+from daft.daft import read_parquet_into_pyarrow_bulk as _read_parquet_into_pyarrow_bulk
 from daft.daft import read_parquet_statistics as _read_parquet_statistics
 from daft.datatype import DataType, TimeUnit
 from daft.expressions import Expression, ExpressionsProjection
@@ -395,6 +396,7 @@ class Table:
         num_rows: int | None = None,
         row_groups_per_path: list[list[int]] | None = None,
         io_config: IOConfig | None = None,
+        num_parallel_tasks: int | None = 128,
         multithreaded_io: bool | None = None,
         coerce_int96_timestamp_unit: TimeUnit = TimeUnit.ns(),
     ) -> list[Table]:
@@ -405,6 +407,7 @@ class Table:
             num_rows=num_rows,
             row_groups=row_groups_per_path,
             io_config=io_config,
+            num_parallel_tasks=num_parallel_tasks,
             multithreaded_io=multithreaded_io,
             coerce_int96_timestamp_unit=coerce_int96_timestamp_unit._timeunit,
         )
@@ -430,7 +433,6 @@ class Table:
 
 
 def _trim_pyarrow_large_arrays(arr: pa.ChunkedArray) -> pa.ChunkedArray:
-
     if pa.types.is_large_binary(arr.type) or pa.types.is_large_string(arr.type):
         if pa.types.is_large_binary(arr.type):
             target_type = pa.binary()
@@ -464,7 +466,6 @@ def read_parquet_into_pyarrow(
     multithreaded_io: bool | None = None,
     coerce_int96_timestamp_unit: TimeUnit = TimeUnit.ns(),
 ) -> pa.Table:
-
     fields, metadata, columns = _read_parquet_into_pyarrow(
         uri=path,
         columns=columns,
@@ -478,3 +479,31 @@ def read_parquet_into_pyarrow(
     schema = pa.schema(fields, metadata=metadata)
     columns = [pa.chunked_array(c) for c in columns]  # type: ignore
     return pa.table(columns, schema=schema)
+
+
+def read_parquet_into_pyarrow_bulk(
+    paths: list[str],
+    columns: list[str] | None = None,
+    start_offset: int | None = None,
+    num_rows: int | None = None,
+    row_groups_per_path: list[list[int]] | None = None,
+    io_config: IOConfig | None = None,
+    num_parallel_tasks: int | None = 128,
+    multithreaded_io: bool | None = None,
+    coerce_int96_timestamp_unit: TimeUnit = TimeUnit.ns(),
+) -> list[pa.Table]:
+    bulk_result = _read_parquet_into_pyarrow_bulk(
+        uris=paths,
+        columns=columns,
+        start_offset=start_offset,
+        num_rows=num_rows,
+        row_groups=row_groups_per_path,
+        io_config=io_config,
+        num_parallel_tasks=num_parallel_tasks,
+        multithreaded_io=multithreaded_io,
+        coerce_int96_timestamp_unit=coerce_int96_timestamp_unit._timeunit,
+    )
+    return [
+        pa.table([pa.chunked_array(c) for c in columns], schema=pa.schema(fields, metadata=metadata))  # type: ignore
+        for fields, metadata, columns in bulk_result
+    ]
