@@ -4,19 +4,42 @@ use std::vec;
 
 use image::{ColorType, DynamicImage, ImageBuffer};
 
+use crate::array::{FixedSizeListArray, ListArray, StructArray};
 use crate::datatypes::{
     logical::{DaftImageryType, FixedShapeImageArray, ImageArray, LogicalArray},
-    BinaryArray, DaftLogicalType, DataType, Field, FixedSizeListArray, ImageFormat, ImageMode,
-    StructArray,
+    BinaryArray, DataType, Field, ImageFormat, ImageMode,
 };
+use crate::datatypes::{UInt16Array, UInt32Array, UInt8Array};
+use crate::{IntoSeries, Series};
 use common_error::{DaftError, DaftResult};
 use image::{Luma, LumaA, Rgb, Rgba};
 
-use super::as_arrow::AsArrow;
+use super::full::FullNull;
+use super::{as_arrow::AsArrow, from_arrow::FromArrow};
 use num_traits::FromPrimitive;
 
 use std::ops::Deref;
 
+#[derive(Clone)]
+pub struct BBox(u32, u32, u32, u32);
+
+impl BBox {
+    pub fn from_u32_arrow_array(arr: &dyn arrow2::array::Array) -> Self {
+        assert!(arr.len() == 4);
+        let mut iter = arr
+            .as_any()
+            .downcast_ref::<arrow2::array::UInt32Array>()
+            .unwrap()
+            .iter();
+        BBox(
+            *iter.next().unwrap().unwrap(),
+            *iter.next().unwrap().unwrap(),
+            *iter.next().unwrap().unwrap(),
+            *iter.next().unwrap().unwrap(),
+        )
+    }
+}
+
 #[allow(clippy::upper_case_acronyms, dead_code)]
 #[derive(Debug)]
 pub enum DaftImageBuffer<'a> {
@@ -203,6 +226,36 @@ impl<'a> DaftImageBuffer<'a> {
             _ => unimplemented!("Mode {self:?} not implemented"),
         }
     }
+
+    pub fn crop(&self, bbox: &BBox) -> Self {
+        // HACK(jay): The `.to_image()` method on SubImage takes in `'static` references for some reason
+        // This hack will ensure that `&self` adheres to that overly prescriptive bound
+        let inner =
+            unsafe { std::mem::transmute::<&DaftImageBuffer<'a>, &DaftImageBuffer<'static>>(self) };
+        match inner {
+            DaftImageBuffer::L(imgbuf) => {
+                let result =
+                    image::imageops::crop_imm(imgbuf, bbox.0, bbox.1, bbox.2, bbox.3).to_image();
+                DaftImageBuffer::L(image_buffer_vec_to_cow(result))
+            }
+            DaftImageBuffer::LA(imgbuf) => {
+                let result =
+                    image::imageops::crop_imm(imgbuf, bbox.0, bbox.1, bbox.2, bbox.3).to_image();
+                DaftImageBuffer::LA(image_buffer_vec_to_cow(result))
+            }
+            DaftImageBuffer::RGB(imgbuf) => {
+                let result =
+                    image::imageops::crop_imm(imgbuf, bbox.0, bbox.1, bbox.2, bbox.3).to_image();
+                DaftImageBuffer::RGB(image_buffer_vec_to_cow(result))
+            }
+            DaftImageBuffer::RGBA(imgbuf) => {
+                let result =
+                    image::imageops::crop_imm(imgbuf, bbox.0, bbox.1, bbox.2, bbox.3).to_image();
+                DaftImageBuffer::RGBA(image_buffer_vec_to_cow(result))
+            }
+            _ => unimplemented!("Mode {self:?} not implemented"),
+        }
+    }
 }
 
 fn image_buffer_vec_to_cow<'a, P, T>(input: ImageBuffer<P, Vec<T>>) -> ImageBuffer<P, Cow<'a, [T]>>
@@ -256,33 +309,33 @@ impl<'a> From<DynamicImage> for DaftImageBuffer<'a> {
     }
 }
 
-pub struct ImageArrayVecs<T> {
-    pub data: Vec<T>,
+pub struct ImageArraySidecarData {
     pub channels: Vec<u16>,
     pub heights: Vec<u32>,
     pub widths: Vec<u32>,
     pub modes: Vec<u8>,
-    pub offsets: Vec<i64>,
     pub validity: Option<arrow2::bitmap::Bitmap>,
 }
 
 pub trait AsImageObj {
+    fn name(&self) -> &str;
+    fn len(&self) -> usize;
     fn as_image_obj(&self, idx: usize) -> Option<DaftImageBuffer<'_>>;
 }
 
-pub struct ImageBufferIter<'a, T>
+pub struct ImageBufferIter<'a, Arr>
 where
-    T: DaftLogicalType + DaftImageryType,
+    Arr: AsImageObj,
 {
     cursor: usize,
-    image_array: &'a LogicalArray<T>,
+    image_array: &'a Arr,
 }
 
-impl<'a, T> ImageBufferIter<'a, T>
+impl<'a, Arr> ImageBufferIter<'a, Arr>
 where
-    T: DaftLogicalType + DaftImageryType,
+    Arr: AsImageObj,
 {
-    pub fn new(image_array: &'a LogicalArray<T>) -> Self {
+    pub fn new(image_array: &'a Arr) -> Self {
         Self {
             cursor: 0usize,
             image_array,
@@ -290,10 +343,9 @@ where
     }
 }
 
-impl<'a, T> Iterator for ImageBufferIter<'a, T>
+impl<'a, Arr> Iterator for ImageBufferIter<'a, Arr>
 where
-    T: DaftLogicalType + DaftImageryType,
-    LogicalArray<T>: AsImageObj,
+    Arr: AsImageObj,
 {
     type Item = Option<DaftImageBuffer<'a>>;
 
@@ -310,116 +362,125 @@ where
 
 impl ImageArray {
     pub fn image_mode(&self) -> &Option<ImageMode> {
-        match self.logical_type() {
+        match self.data_type() {
             DataType::Image(mode) => mode,
             _ => panic!("Expected dtype to be Image"),
         }
     }
 
-    pub fn data_array(&self) -> &arrow2::array::ListArray<i64> {
-        let p = self.physical.as_arrow();
+    pub fn data_array(&self) -> &ListArray {
         const IMAGE_DATA_IDX: usize = 0;
-        let array = p.values().get(IMAGE_DATA_IDX).unwrap();
-        array.as_ref().as_any().downcast_ref().unwrap()
+        let array = self.physical.children.get(IMAGE_DATA_IDX).unwrap();
+        array.list().unwrap()
     }
 
     pub fn channel_array(&self) -> &arrow2::array::UInt16Array {
-        let p = self.physical.as_arrow();
         const IMAGE_CHANNEL_IDX: usize = 1;
-        let array = p.values().get(IMAGE_CHANNEL_IDX).unwrap();
-        array.as_ref().as_any().downcast_ref().unwrap()
+        let array = self.physical.children.get(IMAGE_CHANNEL_IDX).unwrap();
+        array.u16().unwrap().as_arrow()
     }
 
     pub fn height_array(&self) -> &arrow2::array::UInt32Array {
-        let p = self.physical.as_arrow();
         const IMAGE_HEIGHT_IDX: usize = 2;
-        let array = p.values().get(IMAGE_HEIGHT_IDX).unwrap();
-        array.as_ref().as_any().downcast_ref().unwrap()
+        let array = self.physical.children.get(IMAGE_HEIGHT_IDX).unwrap();
+        array.u32().unwrap().as_arrow()
     }
 
     pub fn width_array(&self) -> &arrow2::array::UInt32Array {
-        let p = self.physical.as_arrow();
         const IMAGE_WIDTH_IDX: usize = 3;
-        let array = p.values().get(IMAGE_WIDTH_IDX).unwrap();
-        array.as_ref().as_any().downcast_ref().unwrap()
+        let array = self.physical.children.get(IMAGE_WIDTH_IDX).unwrap();
+        array.u32().unwrap().as_arrow()
     }
 
     pub fn mode_array(&self) -> &arrow2::array::UInt8Array {
-        let p = self.physical.as_arrow();
         const IMAGE_MODE_IDX: usize = 4;
-        let array = p.values().get(IMAGE_MODE_IDX).unwrap();
-        array.as_ref().as_any().downcast_ref().unwrap()
+        let array = self.physical.children.get(IMAGE_MODE_IDX).unwrap();
+        array.u8().unwrap().as_arrow()
     }
 
     pub fn from_vecs<T: arrow2::types::NativeType>(
         name: &str,
         data_type: DataType,
-        vecs: ImageArrayVecs<T>,
+        data: Vec<T>,
+        offsets: Vec<i64>,
+        sidecar_data: ImageArraySidecarData,
     ) -> DaftResult<Self> {
-        if vecs.data.is_empty() {
+        if data.is_empty() {
             // Create an all-null array if the data array is empty.
-            let physical_type = data_type.to_physical();
-            let null_struct_array =
-                arrow2::array::new_null_array(physical_type.to_arrow()?, vecs.channels.len());
-            let daft_struct_array =
-                StructArray::new(Field::new(name, physical_type).into(), null_struct_array)?;
             return Ok(ImageArray::new(
-                Field::new(name, data_type),
-                daft_struct_array,
+                Field::new(name, data_type.clone()),
+                StructArray::empty(name, &data_type.to_physical()),
             ));
         }
-        let offsets = arrow2::offset::OffsetsBuffer::try_from(vecs.offsets)?;
+        let offsets = arrow2::offset::OffsetsBuffer::try_from(offsets)?;
         let arrow_dtype: arrow2::datatypes::DataType = T::PRIMITIVE.into();
         if let DataType::Image(Some(mode)) = &data_type {
             if mode.get_dtype().to_arrow()? != arrow_dtype {
                 panic!("Inner value dtype of provided dtype {data_type:?} is inconsistent with inferred value dtype {arrow_dtype:?}");
             }
         }
-
-        let list_datatype = arrow2::datatypes::DataType::LargeList(Box::new(
-            arrow2::datatypes::Field::new("data", arrow_dtype, true),
-        ));
-        let data_array = Box::new(arrow2::array::ListArray::<i64>::new(
-            list_datatype,
+        let data_array = ListArray::new(
+            Field::new("data", DataType::List(Box::new((&arrow_dtype).into()))),
+            Series::try_from((
+                "data",
+                Box::new(arrow2::array::PrimitiveArray::from_vec(data))
+                    as Box<dyn arrow2::array::Array>,
+            ))?,
             offsets,
-            Box::new(arrow2::array::PrimitiveArray::from_vec(vecs.data)),
-            vecs.validity.clone(),
-        ));
+            sidecar_data.validity.clone(),
+        );
 
-        let values: Vec<Box<dyn arrow2::array::Array>> = vec![
-            data_array,
-            Box::new(
-                arrow2::array::UInt16Array::from_vec(vecs.channels)
-                    .with_validity(vecs.validity.clone()),
-            ),
-            Box::new(
-                arrow2::array::UInt32Array::from_vec(vecs.heights)
-                    .with_validity(vecs.validity.clone()),
-            ),
-            Box::new(
-                arrow2::array::UInt32Array::from_vec(vecs.widths)
-                    .with_validity(vecs.validity.clone()),
-            ),
-            Box::new(
-                arrow2::array::UInt8Array::from_vec(vecs.modes)
-                    .with_validity(vecs.validity.clone()),
-            ),
+        Self::from_list_array(name, data_type, data_array, sidecar_data)
+    }
+
+    pub fn from_list_array(
+        name: &str,
+        data_type: DataType,
+        data_array: ListArray,
+        sidecar_data: ImageArraySidecarData,
+    ) -> DaftResult<Self> {
+        let values: Vec<Series> = vec![
+            data_array.into_series().rename("data"),
+            UInt16Array::from((
+                "channel",
+                Box::new(
+                    arrow2::array::UInt16Array::from_vec(sidecar_data.channels)
+                        .with_validity(sidecar_data.validity.clone()),
+                ),
+            ))
+            .into_series(),
+            UInt32Array::from((
+                "height",
+                Box::new(
+                    arrow2::array::UInt32Array::from_vec(sidecar_data.heights)
+                        .with_validity(sidecar_data.validity.clone()),
+                ),
+            ))
+            .into_series(),
+            UInt32Array::from((
+                "width",
+                Box::new(
+                    arrow2::array::UInt32Array::from_vec(sidecar_data.widths)
+                        .with_validity(sidecar_data.validity.clone()),
+                ),
+            ))
+            .into_series(),
+            UInt8Array::from((
+                "mode",
+                Box::new(
+                    arrow2::array::UInt8Array::from_vec(sidecar_data.modes)
+                        .with_validity(sidecar_data.validity.clone()),
+                ),
+            ))
+            .into_series(),
         ];
         let physical_type = data_type.to_physical();
-        let struct_array = Box::new(arrow2::array::StructArray::new(
-            physical_type.to_arrow()?,
+        let struct_array = StructArray::new(
+            Field::new(name, physical_type),
             values,
-            vecs.validity,
-        ));
-
-        let daft_struct_array = crate::datatypes::StructArray::new(
-            Field::new(name, physical_type).into(),
-            struct_array,
-        )?;
-        Ok(ImageArray::new(
-            Field::new(name, data_type),
-            daft_struct_array,
-        ))
+            sidecar_data.validity,
+        );
+        Ok(ImageArray::new(Field::new(name, data_type), struct_array))
     }
 
     pub fn encode(&self, image_format: ImageFormat) -> DaftResult<BinaryArray> {
@@ -431,6 +492,22 @@ impl ImageArray {
         Self::from_daft_image_buffers(self.name(), result.as_slice(), self.image_mode())
     }
 
+    pub fn crop(&self, bboxes: &FixedSizeListArray) -> DaftResult<ImageArray> {
+        let mut bboxes_iterator: Box<dyn Iterator<Item = Option<BBox>>> = if bboxes.len() == 1 {
+            Box::new(std::iter::repeat(bboxes.get(0).map(|bbox| {
+                BBox::from_u32_arrow_array(bbox.u32().unwrap().data())
+            })))
+        } else {
+            Box::new((0..bboxes.len()).map(|i| {
+                bboxes
+                    .get(i)
+                    .map(|bbox| BBox::from_u32_arrow_array(bbox.u32().unwrap().data()))
+            }))
+        };
+        let result = crop_images(self, &mut bboxes_iterator);
+        Self::from_daft_image_buffers(self.name(), result.as_slice(), self.image_mode())
+    }
+
     pub fn resize_to_fixed_shape_image_array(
         &self,
         w: u32,
@@ -484,13 +561,13 @@ impl ImageArray {
         Self::from_vecs(
             name,
             DataType::Image(*image_mode),
-            ImageArrayVecs {
-                data,
+            data,
+            offsets,
+            ImageArraySidecarData {
                 channels,
                 heights,
                 widths,
                 modes,
-                offsets,
                 validity,
             },
         )
@@ -498,6 +575,14 @@ impl ImageArray {
 }
 
 impl AsImageObj for ImageArray {
+    fn len(&self) -> usize {
+        ImageArray::len(self)
+    }
+
+    fn name(&self) -> &str {
+        ImageArray::name(self)
+    }
+
     fn as_image_obj<'a>(&'a self, idx: usize) -> Option<DaftImageBuffer<'a>> {
         assert!(idx < self.len());
         if !self.physical.is_valid(idx) {
@@ -516,8 +601,10 @@ impl AsImageObj for ImageArray {
         let end = *offsets.get(idx + 1).unwrap() as usize;
 
         let values = da
-            .values()
-            .as_ref()
+            .flat_child
+            .u8()
+            .unwrap()
+            .data()
             .as_any()
             .downcast_ref::<arrow2::array::UInt8Array>()
             .unwrap();
@@ -551,6 +638,13 @@ impl AsImageObj for ImageArray {
 }
 
 impl FixedShapeImageArray {
+    fn mode(&self) -> ImageMode {
+        match &self.field.dtype {
+            DataType::FixedShapeImage(mode, _, _) => *mode,
+            _ => panic!("FixedShapeImageArray does not have the correct FixedShapeImage dtype"),
+        }
+    }
+
     pub fn from_daft_image_buffers(
         name: &str,
         inputs: &[Option<DaftImageBuffer<'_>>],
@@ -597,10 +691,8 @@ impl FixedShapeImageArray {
             Box::new(arrow2::array::PrimitiveArray::from_vec(data)),
             validity,
         ));
-        let physical_array = FixedSizeListArray::new(
-            Field::new(name, (&arrow_dtype).into()).into(),
-            arrow_array.boxed(),
-        )?;
+        let physical_array =
+            FixedSizeListArray::from_arrow(&Field::new(name, (&arrow_dtype).into()), arrow_array)?;
         let logical_dtype = DataType::FixedShapeImage(*image_mode, height, width);
         Ok(Self::new(Field::new(name, logical_dtype), physical_array))
     }
@@ -611,23 +703,47 @@ impl FixedShapeImageArray {
 
     pub fn resize(&self, w: u32, h: u32) -> DaftResult<Self> {
         let result = resize_images(self, w, h);
-        match self.logical_type() {
+        match self.data_type() {
             DataType::FixedShapeImage(mode, _, _) => Self::from_daft_image_buffers(self.name(), result.as_slice(), mode, h, w),
             dt => panic!("FixedShapeImageArray should always have DataType::FixedShapeImage() as it's dtype, but got {}", dt),
         }
     }
+
+    pub fn crop(&self, bboxes: &FixedSizeListArray) -> DaftResult<ImageArray> {
+        let mut bboxes_iterator: Box<dyn Iterator<Item = Option<BBox>>> = if bboxes.len() == 1 {
+            Box::new(std::iter::repeat(bboxes.get(0).map(|bbox| {
+                BBox::from_u32_arrow_array(bbox.u32().unwrap().data())
+            })))
+        } else {
+            Box::new((0..bboxes.len()).map(|i| {
+                bboxes
+                    .get(i)
+                    .map(|bbox| BBox::from_u32_arrow_array(bbox.u32().unwrap().data()))
+            }))
+        };
+        let result = crop_images(self, &mut bboxes_iterator);
+        ImageArray::from_daft_image_buffers(self.name(), result.as_slice(), &Some(self.mode()))
+    }
 }
 
 impl AsImageObj for FixedShapeImageArray {
+    fn len(&self) -> usize {
+        FixedShapeImageArray::len(self)
+    }
+
+    fn name(&self) -> &str {
+        FixedShapeImageArray::name(self)
+    }
+
     fn as_image_obj<'a>(&'a self, idx: usize) -> Option<DaftImageBuffer<'a>> {
         assert!(idx < self.len());
         if !self.physical.is_valid(idx) {
             return None;
         }
 
-        match self.logical_type() {
+        match self.data_type() {
             DataType::FixedShapeImage(mode, height, width) => {
-                let arrow_array = self.as_arrow().values().as_any().downcast_ref::<arrow2::array::UInt8Array>().unwrap();
+                let arrow_array = self.physical.flat_child.downcast::<UInt8Array>().unwrap().as_arrow();
                 let num_channels = mode.num_channels();
                 let size = height * width * num_channels as u32;
                 let start = idx * size as usize;
@@ -664,7 +780,7 @@ where
     LogicalArray<T>: AsImageObj,
 {
     type Item = Option<DaftImageBuffer<'a>>;
-    type IntoIter = ImageBufferIter<'a, T>;
+    type IntoIter = ImageBufferIter<'a, LogicalArray<T>>;
 
     fn into_iter(self) -> Self::IntoIter {
         ImageBufferIter::new(self)
@@ -707,15 +823,10 @@ impl BinaryArray {
     }
 }
 
-fn encode_images<'a, T>(
-    images: &'a LogicalArray<T>,
-    image_format: ImageFormat,
-) -> DaftResult<BinaryArray>
+fn encode_images<'a, Arr>(images: &'a Arr, image_format: ImageFormat) -> DaftResult<BinaryArray>
 where
-    T: DaftImageryType,
-    LogicalArray<T>: AsImageObj,
-    &'a LogicalArray<T>:
-        IntoIterator<Item = Option<DaftImageBuffer<'a>>, IntoIter = ImageBufferIter<'a, T>>,
+    Arr: AsImageObj,
+    &'a Arr: IntoIterator<Item = Option<DaftImageBuffer<'a>>, IntoIter = ImageBufferIter<'a, Arr>>,
 {
     let arrow_array = match image_format {
         ImageFormat::TIFF => {
@@ -746,7 +857,7 @@ where
                     .transpose()
                 })
                 .collect::<DaftResult<Vec<_>>>()?;
-            arrow2::array::BinaryArray::<i64>::from_iter(values.into_iter())
+            arrow2::array::BinaryArray::<i64>::from_iter(values)
         }
         _ => {
             let mut offsets = Vec::with_capacity(images.len() + 1);
@@ -803,15 +914,31 @@ where
     )
 }
 
-fn resize_images<'a, T>(images: &'a LogicalArray<T>, w: u32, h: u32) -> Vec<Option<DaftImageBuffer>>
+fn resize_images<'a, Arr>(images: &'a Arr, w: u32, h: u32) -> Vec<Option<DaftImageBuffer>>
 where
-    T: DaftImageryType,
-    LogicalArray<T>: AsImageObj,
-    &'a LogicalArray<T>:
-        IntoIterator<Item = Option<DaftImageBuffer<'a>>, IntoIter = ImageBufferIter<'a, T>>,
+    Arr: AsImageObj,
+    &'a Arr: IntoIterator<Item = Option<DaftImageBuffer<'a>>, IntoIter = ImageBufferIter<'a, Arr>>,
 {
     images
         .into_iter()
         .map(|img| img.map(|img| img.resize(w, h)))
         .collect::<Vec<_>>()
 }
+
+fn crop_images<'a, Arr>(
+    images: &'a Arr,
+    bboxes: &mut dyn Iterator<Item = Option<BBox>>,
+) -> Vec<Option<DaftImageBuffer<'a>>>
+where
+    Arr: AsImageObj,
+    &'a Arr: IntoIterator<Item = Option<DaftImageBuffer<'a>>, IntoIter = ImageBufferIter<'a, Arr>>,
+{
+    images
+        .into_iter()
+        .zip(bboxes)
+        .map(|(img, bbox)| match (img, bbox) {
+            (None, _) | (_, None) => None,
+            (Some(img), Some(bbox)) => Some(img.crop(&bbox)),
+        })
+        .collect::<Vec<_>>()
+}
