@@ -1,7 +1,9 @@
+mod crop;
 mod decode;
 mod encode;
 mod resize;
 
+use crop::CropEvaluator;
 use decode::DecodeEvaluator;
 use encode::EncodeEvaluator;
 use resize::ResizeEvaluator;
@@ -13,11 +15,12 @@ use crate::Expr;
 
 use super::FunctionEvaluator;
 
-#[derive(Debug, Clone, Serialize, Deserialize, PartialEq)]
+#[derive(Debug, Clone, Serialize, Deserialize, PartialEq, Eq, Hash)]
 pub enum ImageExpr {
     Decode(),
     Encode { image_format: ImageFormat },
     Resize { w: u32, h: u32 },
+    Crop(),
 }
 
 impl ImageExpr {
@@ -29,6 +32,7 @@ impl ImageExpr {
             Decode() => &DecodeEvaluator {},
             Encode { .. } => &EncodeEvaluator {},
             Resize { .. } => &ResizeEvaluator {},
+            Crop { .. } => &CropEvaluator {},
         }
     }
 }
@@ -53,3 +57,10 @@ pub fn resize(input: &Expr, w: u32, h: u32) -> Expr {
         inputs: vec![input.clone()],
     }
 }
+
+pub fn crop(input: &Expr, bbox: &Expr) -> Expr {
+    Expr::Function {
+        func: super::FunctionExpr::Image(ImageExpr::Crop()),
+        inputs: vec![input.clone(), bbox.clone()],
+    }
+}
