@@ -15,8 +15,7 @@ impl FunctionEvaluator for ExplodeEvaluator {
         match inputs {
             [input] => {
                 let field = input.to_field(schema)?;
-                let exploded_dtype = field.dtype.get_exploded_dtype()?;
-                Ok(Field::new(field.name, exploded_dtype.clone()))
+                field.to_exploded_field()
             }
             _ => Err(DaftError::SchemaMismatch(format!(
                 "Expected 1 input arg, got {}",
