@@ -9,9 +9,9 @@ use crate::Expr;
 
 use super::FunctionEvaluator;
 
-use daft_io::config::IOConfig;
+use common_io_config::IOConfig;
 
-#[derive(Debug, Clone, Serialize, Deserialize, PartialEq)]
+#[derive(Debug, Clone, Serialize, Deserialize, PartialEq, Eq, Hash)]
 pub enum UriExpr {
     Download {
         max_connections: usize,
