@@ -1,5 +1,5 @@
 #![feature(async_closure)]
-
+#![feature(let_chains)]
 mod azure_blob;
 mod google_cloud;
 mod http;
@@ -84,6 +84,12 @@ pub enum Error {
     #[snafu(display("Unhandled Error for path: {}\nDetails:\n{}", path, msg))]
     Unhandled { path: String, msg: String },
 
+    #[snafu(
+        display("Error sending data over a tokio channel: {}", source),
+        context(false)
+    )]
+    UnableToSendDataOverChannel { source: DynError },
+
     #[snafu(display("Error joining spawned task: {}", source), context(false))]
     JoinError { source: tokio::task::JoinError },
 }
@@ -244,6 +250,10 @@ fn parse_url(input: &str) -> Result<(SourceType, Cow<'_, str>)> {
         "s3" => Ok((SourceType::S3, fixed_input)),
         "az" | "abfs" => Ok((SourceType::AzureBlob, fixed_input)),
         "gcs" | "gs" => Ok((SourceType::GCS, fixed_input)),
+        #[cfg(target_env = "msvc")]
+        _ if scheme.len() == 1 && ("a" <= scheme.as_str() && (scheme.as_str() <= "z")) => {
+            Ok((SourceType::File, Cow::Owned(format!("file://{input}"))))
+        }
         _ => Err(Error::NotImplementedSource { store: scheme }),
     }
 }
