@@ -100,6 +100,10 @@ enum Error {
         "Unable to parse data as Utf8 while reading header for file: {path}. {source}"
     ))]
     UnableToParseUtf8 { path: String, source: FromUtf8Error },
+    #[snafu(display("Unable to create TlsConnector. {source}"))]
+    UnableToCreateTlsConnector {
+        source: hyper_tls::native_tls::Error,
+    },
 }
 
 impl From<Error> for super::Error {
@@ -134,6 +138,20 @@ impl From<Error> for super::Error {
                     source: err.into(),
                 },
             },
+            UnableToListObjects { path, source } => match source.into_service_error() {
+                ListObjectsV2Error::NoSuchBucket(no_such_key) => super::Error::NotFound {
+                    path,
+                    source: no_such_key.into(),
+                },
+                ListObjectsV2Error::Unhandled(v) => super::Error::Unhandled {
+                    path,
+                    msg: DisplayErrorContext(v).to_string(),
+                },
+                err => super::Error::UnableToOpenFile {
+                    path,
+                    source: err.into(),
+                },
+            },
             InvalidUrl { path, source } => super::Error::InvalidUrl { path, source },
             UnableToReadBytes { path, source } => super::Error::UnableToReadBytes {
                 path,
@@ -160,6 +178,35 @@ impl From<Error> for super::Error {
     }
 }
 
+fn handle_https_client_settings(
+    builder: aws_sdk_s3::config::Builder,
+    config: &S3Config,
+) -> super::Result<aws_sdk_s3::config::Builder> {
+    let tls_connector = hyper_tls::native_tls::TlsConnector::builder()
+        .danger_accept_invalid_certs(!config.verify_ssl)
+        .danger_accept_invalid_hostnames((!config.verify_ssl) || (!config.check_hostname_ssl))
+        .build()
+        .context(UnableToCreateTlsConnectorSnafu {})?;
+    let mut http_connector = hyper::client::HttpConnector::new();
+    http_connector.enforce_http(false);
+    let https_connector = hyper_tls::HttpsConnector::<hyper::client::HttpConnector>::from((
+        http_connector,
+        tls_connector.into(),
+    ));
+    use aws_smithy_client::http_connector::ConnectorSettings;
+    use aws_smithy_client::hyper_ext;
+    let smithy_client = hyper_ext::Adapter::builder()
+        .connector_settings(
+            ConnectorSettings::builder()
+                .connect_timeout(Duration::from_millis(config.connect_timeout_ms))
+                .read_timeout(Duration::from_millis(config.read_timeout_ms))
+                .build(),
+        )
+        .build(https_connector);
+    let builder = builder.http_connector(smithy_client);
+    Ok(builder)
+}
+
 async fn build_s3_client(config: &S3Config) -> super::Result<(bool, s3::Client)> {
     const DEFAULT_REGION: Region = Region::from_static("us-east-1");
 
@@ -173,7 +220,7 @@ async fn build_s3_client(config: &S3Config) -> super::Result<(bool, s3::Client)>
     let builder = aws_sdk_s3::config::Builder::from(&conf);
     let builder = match &config.endpoint_url {
         None => builder,
-        Some(endpoint) => builder.endpoint_url(endpoint),
+        Some(endpoint) => builder.endpoint_url(endpoint).force_path_style(true),
     };
     let builder = if let Some(region) = &config.region_name {
         builder.region(Region::new(region.to_owned()))
@@ -207,6 +254,8 @@ async fn build_s3_client(config: &S3Config) -> super::Result<(bool, s3::Client)>
 
     let builder = builder.retry_config(retry_config);
 
+    let builder = handle_https_client_settings(builder, config)?;
+
     let sleep_impl = Arc::new(TokioSleep::new());
     let builder = builder.sleep_impl(sleep_impl);
     let timeout_config = TimeoutConfig::builder()
@@ -303,6 +352,7 @@ impl S3LikeSource {
         range: Option<Range<usize>>,
         region: &Region,
     ) -> super::Result<GetResult> {
+        log::debug!("S3 get at {uri}, range: {range:?}, in region: {region}");
         let parsed = url::Url::parse(uri).with_context(|_| InvalidUrlSnafu { path: uri })?;
         let bucket = match parsed.host_str() {
             Some(s) => Ok(s),
@@ -313,6 +363,7 @@ impl S3LikeSource {
         }?;
         let key = parsed.path();
         if let Some(key) = key.strip_prefix('/') {
+            log::debug!("S3 get parsed uri: {uri} into Bucket: {bucket}, Key: {key}");
             let request = self
                 .get_s3_client(region)
                 .await?
@@ -412,6 +463,7 @@ impl S3LikeSource {
         uri: &str,
         region: &Region,
     ) -> super::Result<usize> {
+        log::debug!("S3 head at {uri} in region: {region}");
         let parsed = url::Url::parse(uri).with_context(|_| InvalidUrlSnafu { path: uri })?;
 
         let bucket = match parsed.host_str() {
@@ -423,6 +475,7 @@ impl S3LikeSource {
         }?;
         let key = parsed.path();
         if let Some(key) = key.strip_prefix('/') {
+            log::debug!("S3 head parsed uri: {uri} into Bucket: {bucket}, Key: {key}");
             let request = self
                 .get_s3_client(region)
                 .await?
@@ -488,16 +541,19 @@ impl S3LikeSource {
         }
     }
 
+    #[allow(clippy::too_many_arguments)]
     #[async_recursion]
     async fn _list_impl(
         &self,
         _permit: SemaphorePermit<'async_recursion>,
+        scheme: &str,
         bucket: &str,
         key: &str,
         delimiter: String,
         continuation_token: Option<String>,
         region: &Region,
     ) -> super::Result<LSResult> {
+        log::debug!("S3 list_objects: Bucket: {bucket}, Key: {key}, continuation_token: {continuation_token:?} in region: {region}");
         let request = self
             .get_s3_client(region)
             .await?
@@ -533,12 +589,12 @@ impl S3LikeSource {
         } else {
             request.send().await
         };
-        let uri = &format!("s3://{bucket}/{key}");
+        let uri = &format!("{scheme}://{bucket}/{key}");
         match response {
             Ok(v) => {
                 let dirs = v.common_prefixes();
                 let files = v.contents();
-                let continuation_token = v.continuation_token().map(|s| s.to_string());
+                let continuation_token = v.next_continuation_token().map(|s| s.to_string());
                 let mut total_len = 0;
                 if let Some(dirs) = dirs {
                     total_len += dirs.len()
@@ -550,7 +606,10 @@ impl S3LikeSource {
                 if let Some(dirs) = dirs {
                     for d in dirs {
                         let fmeta = FileMetadata {
-                            filepath: format!("s3://{bucket}/{}", d.prefix().unwrap_or_default()),
+                            filepath: format!(
+                                "{scheme}://{bucket}/{}",
+                                d.prefix().unwrap_or_default()
+                            ),
                             size: None,
                             filetype: FileType::Directory,
                         };
@@ -560,7 +619,10 @@ impl S3LikeSource {
                 if let Some(files) = files {
                     for f in files {
                         let fmeta = FileMetadata {
-                            filepath: format!("s3://{bucket}/{}", f.key().unwrap_or_default()),
+                            filepath: format!(
+                                "{scheme}://{bucket}/{}",
+                                f.key().unwrap_or_default()
+                            ),
                             size: Some(f.size() as u64),
                             filetype: FileType::File,
                         };
@@ -592,6 +654,7 @@ impl S3LikeSource {
                         log::debug!("S3 Region of {uri} different than client {:?} vs {:?} Attempting List in that region with new client", new_region, region);
                         self._list_impl(
                             _permit,
+                            scheme,
                             bucket,
                             key,
                             delimiter,
@@ -640,7 +703,9 @@ impl ObjectSource for S3LikeSource {
         continuation_token: Option<&str>,
     ) -> super::Result<LSResult> {
         let parsed = url::Url::parse(path).with_context(|_| InvalidUrlSnafu { path })?;
+        let scheme = parsed.scheme();
         let delimiter = delimiter.unwrap_or("/");
+
         let bucket = match parsed.host_str() {
             Some(s) => Ok(s),
             None => Err(Error::InvalidUrl {
@@ -649,58 +714,63 @@ impl ObjectSource for S3LikeSource {
             }),
         }?;
         let key = parsed.path();
+        let key = key
+            .trim_start_matches(delimiter)
+            .trim_end_matches(delimiter);
+        let key = if key.is_empty() {
+            "".to_string()
+        } else {
+            format!("{key}{delimiter}")
+        };
 
-        if let Some(key) = key.strip_prefix('/') {
-            // assume its a directory first
-            let key = format!("{}/", key.strip_suffix('/').unwrap_or(key));
-            let lsr = {
-                let permit = self
-                    .connection_pool_sema
-                    .acquire()
-                    .await
-                    .context(UnableToGrabSemaphoreSnafu)?;
-                self._list_impl(
+        // assume its a directory first
+        let lsr = {
+            let permit = self
+                .connection_pool_sema
+                .acquire()
+                .await
+                .context(UnableToGrabSemaphoreSnafu)?;
+
+            self._list_impl(
+                permit,
+                scheme,
+                bucket,
+                &key,
+                delimiter.into(),
+                continuation_token.map(String::from),
+                &self.default_region,
+            )
+            .await?
+        };
+        if lsr.files.is_empty() && key.contains(delimiter) {
+            let permit = self
+                .connection_pool_sema
+                .acquire()
+                .await
+                .context(UnableToGrabSemaphoreSnafu)?;
+            // Might be a File
+            let key = key.trim_end_matches(delimiter);
+            let mut lsr = self
+                ._list_impl(
                     permit,
+                    scheme,
                     bucket,
-                    &key,
+                    key,
                     delimiter.into(),
                     continuation_token.map(String::from),
                     &self.default_region,
                 )
-                .await?
-            };
-            if lsr.files.is_empty() && key.contains('/') {
-                let permit = self
-                    .connection_pool_sema
-                    .acquire()
-                    .await
-                    .context(UnableToGrabSemaphoreSnafu)?;
-                // Might be a File
-                let split = key.rsplit_once('/');
-                let (new_key, _) = split.unwrap();
-                let mut lsr = self
-                    ._list_impl(
-                        permit,
-                        bucket,
-                        new_key,
-                        delimiter.into(),
-                        continuation_token.map(String::from),
-                        &self.default_region,
-                    )
-                    .await?;
-                let target_path = format!("s3://{bucket}/{new_key}");
-                lsr.files.retain(|f| f.filepath == target_path);
+                .await?;
+            let target_path = format!("{scheme}://{bucket}/{key}");
+            lsr.files.retain(|f| f.filepath == target_path);
 
-                if lsr.files.is_empty() {
-                    // Isnt a file or a directory
-                    return Err(Error::NotFound { path: path.into() }.into());
-                }
-                Ok(lsr)
-            } else {
-                Ok(lsr)
+            if lsr.files.is_empty() {
+                // Isnt a file or a directory
+                return Err(Error::NotFound { path: path.into() }.into());
             }
+            Ok(lsr)
         } else {
-            Err(Error::NotAFile { path: path.into() }.into())
+            Ok(lsr)
         }
     }
 }
