@@ -9,7 +9,7 @@ use daft_core::{
 };
 use daft_io::{get_runtime, IOClient};
 use daft_table::Table;
-use futures::future::{join_all, try_join_all};
+use futures::{future::join_all, StreamExt, TryStreamExt};
 use snafu::ResultExt;
 
 use crate::{file::ParquetReaderBuilder, JoinSnafu};
@@ -285,7 +285,7 @@ pub fn read_parquet(
     })
 }
 pub type ArrowChunk = Vec<Box<dyn arrow2::array::Array>>;
-
+pub type ParquetPyarrowChunk = (arrow2::datatypes::SchemaRef, Vec<ArrowChunk>);
 #[allow(clippy::too_many_arguments)]
 pub fn read_parquet_into_pyarrow(
     uri: &str,
@@ -296,7 +296,7 @@ pub fn read_parquet_into_pyarrow(
     io_client: Arc<IOClient>,
     multithreaded_io: bool,
     schema_infer_options: &ParquetSchemaInferenceOptions,
-) -> DaftResult<(arrow2::datatypes::SchemaRef, Vec<ArrowChunk>)> {
+) -> DaftResult<ParquetPyarrowChunk> {
     let runtime_handle = get_runtime(multithreaded_io)?;
     let _rt_guard = runtime_handle.enter();
     runtime_handle.block_on(async {
@@ -321,6 +321,7 @@ pub fn read_parquet_bulk(
     num_rows: Option<usize>,
     row_groups: Option<Vec<Vec<i64>>>,
     io_client: Arc<IOClient>,
+    num_parallel_tasks: usize,
     multithreaded_io: bool,
     schema_infer_options: &ParquetSchemaInferenceOptions,
 ) -> DaftResult<Vec<Table>> {
@@ -338,7 +339,7 @@ pub fn read_parquet_bulk(
     }
     let tables = runtime_handle
         .block_on(async move {
-            try_join_all(uris.iter().enumerate().map(|(i, uri)| {
+            let task_stream = futures::stream::iter(uris.iter().enumerate().map(|(i, uri)| {
                 let uri = uri.to_string();
                 let owned_columns = owned_columns.clone();
                 let owned_row_group = match &row_groups {
@@ -352,22 +353,96 @@ pub fn read_parquet_bulk(
                     let columns = owned_columns
                         .as_ref()
                         .map(|s| s.iter().map(AsRef::as_ref).collect::<Vec<_>>());
-                    read_parquet_single(
-                        &uri,
-                        columns.as_deref(),
-                        start_offset,
-                        num_rows,
-                        owned_row_group.as_deref(),
-                        io_client,
-                        &schema_infer_options,
-                    )
-                    .await
+                    Ok((
+                        i,
+                        read_parquet_single(
+                            &uri,
+                            columns.as_deref(),
+                            start_offset,
+                            num_rows,
+                            owned_row_group.as_deref(),
+                            io_client,
+                            &schema_infer_options,
+                        )
+                        .await?,
+                    ))
+                })
+            }));
+            task_stream
+                .buffer_unordered(num_parallel_tasks)
+                .try_collect::<Vec<_>>()
+                .await
+        })
+        .context(JoinSnafu { path: "UNKNOWN" })?;
+
+    let mut collected = tables.into_iter().collect::<DaftResult<Vec<_>>>()?;
+    collected.sort_by_key(|(idx, _)| *idx);
+    Ok(collected.into_iter().map(|(_, v)| v).collect())
+}
+
+#[allow(clippy::too_many_arguments)]
+pub fn read_parquet_into_pyarrow_bulk(
+    uris: &[&str],
+    columns: Option<&[&str]>,
+    start_offset: Option<usize>,
+    num_rows: Option<usize>,
+    row_groups: Option<Vec<Vec<i64>>>,
+    io_client: Arc<IOClient>,
+    num_parallel_tasks: usize,
+    multithreaded_io: bool,
+    schema_infer_options: &ParquetSchemaInferenceOptions,
+) -> DaftResult<Vec<ParquetPyarrowChunk>> {
+    let runtime_handle = get_runtime(multithreaded_io)?;
+    let _rt_guard = runtime_handle.enter();
+    let owned_columns = columns.map(|s| s.iter().map(|v| String::from(*v)).collect::<Vec<_>>());
+    if let Some(ref row_groups) = row_groups {
+        if row_groups.len() != uris.len() {
+            return Err(common_error::DaftError::ValueError(format!(
+                "Mismatch of length of `uris` and `row_groups`. {} vs {}",
+                uris.len(),
+                row_groups.len()
+            )));
+        }
+    }
+    let tables = runtime_handle
+        .block_on(async move {
+            futures::stream::iter(uris.iter().enumerate().map(|(i, uri)| {
+                let uri = uri.to_string();
+                let owned_columns = owned_columns.clone();
+                let owned_row_group = match &row_groups {
+                    None => None,
+                    Some(v) => v.get(i).cloned(),
+                };
+
+                let io_client = io_client.clone();
+                let schema_infer_options = schema_infer_options.clone();
+                tokio::task::spawn(async move {
+                    let columns = owned_columns
+                        .as_ref()
+                        .map(|s| s.iter().map(AsRef::as_ref).collect::<Vec<_>>());
+                    Ok((
+                        i,
+                        read_parquet_single_into_arrow(
+                            &uri,
+                            columns.as_deref(),
+                            start_offset,
+                            num_rows,
+                            owned_row_group.as_deref(),
+                            io_client,
+                            &schema_infer_options,
+                        )
+                        .await?,
+                    ))
                 })
             }))
+            .buffer_unordered(num_parallel_tasks)
+            .try_collect::<Vec<_>>()
             .await
         })
         .context(JoinSnafu { path: "UNKNOWN" })?;
-    tables.into_iter().collect::<DaftResult<Vec<_>>>()
+    let mut collected = tables.into_iter().collect::<DaftResult<Vec<_>>>()?;
+    collected.sort_by_key(|(idx, _)| *idx);
+    Ok(collected.into_iter().map(|(_, v)| v).collect())
 }
 
 pub fn read_parquet_schema(
