@@ -3,8 +3,8 @@
 mod builder;
 mod display;
 mod join;
+mod logical_ops;
 mod logical_plan;
-mod ops;
 mod optimization;
 mod partitioning;
 mod physical_ops;
@@ -23,12 +23,12 @@ pub use partitioning::{PartitionScheme, PartitionSpec};
 pub use physical_plan::PhysicalPlanScheduler;
 pub use resource_request::ResourceRequest;
 pub use source_info::{
-    CsvSourceConfig, FileFormat, FileInfo, FileInfos, JsonSourceConfig, ParquetSourceConfig,
-    PyFileFormatConfig,
+    CsvSourceConfig, FileFormat, FileInfo, FileInfos, JsonSourceConfig, NativeStorageConfig,
+    ParquetSourceConfig, PyFileFormatConfig, PyStorageConfig,
 };
 
 #[cfg(feature = "python")]
-use pyo3::prelude::*;
+use {pyo3::prelude::*, source_info::PythonStorageConfig};
 
 #[cfg(feature = "python")]
 pub fn register_modules(_py: Python, parent: &PyModule) -> PyResult<()> {
@@ -45,6 +45,9 @@ pub fn register_modules(_py: Python, parent: &PyModule) -> PyResult<()> {
     parent.add_class::<ResourceRequest>()?;
     parent.add_class::<FileInfos>()?;
     parent.add_class::<FileInfo>()?;
+    parent.add_class::<PyStorageConfig>()?;
+    parent.add_class::<NativeStorageConfig>()?;
+    parent.add_class::<PythonStorageConfig>()?;
 
     Ok(())
 }
