@@ -3,7 +3,8 @@ use {
     crate::{
         sink_info::OutputFileInfo,
         source_info::{
-            ExternalInfo, FileFormat, FileFormatConfig, FileInfos, InMemoryInfo, PyFileFormatConfig,
+            ExternalInfo, FileFormat, FileFormatConfig, FileInfos, InMemoryInfo,
+            PyFileFormatConfig, PyStorageConfig, StorageConfig,
         },
     },
     daft_core::python::schema::PySchema,
@@ -11,10 +12,8 @@ use {
     daft_dsl::python::PyExpr,
     daft_dsl::Expr,
     pyo3::{
-        exceptions::PyValueError,
-        pyclass, pymethods,
-        types::{PyBytes, PyTuple},
-        PyObject, PyRef, PyRefMut, PyResult, Python,
+        pyclass, pymethods, types::PyBytes, PyObject, PyRef, PyRefMut, PyResult, PyTypeInfo,
+        Python, ToPyObject,
     },
     std::collections::HashMap,
 };
@@ -25,6 +24,7 @@ use std::sync::Arc;
 
 use crate::physical_ops::*;
 
+/// Physical plan for a Daft query.
 #[derive(Debug, Serialize, Deserialize)]
 pub enum PhysicalPlan {
     #[cfg(feature = "python")]
@@ -53,7 +53,8 @@ pub enum PhysicalPlan {
     TabularWriteCsv(TabularWriteCsv),
 }
 
-#[cfg_attr(feature = "python", pyclass)]
+/// A work scheduler for physical plans.
+#[cfg_attr(feature = "python", pyclass(module = "daft.daft"))]
 #[derive(Debug, Serialize, Deserialize)]
 pub struct PhysicalPlanScheduler {
     plan: Arc<PhysicalPlan>,
@@ -62,30 +63,13 @@ pub struct PhysicalPlanScheduler {
 #[cfg(feature = "python")]
 #[pymethods]
 impl PhysicalPlanScheduler {
-    #[new]
-    #[pyo3(signature = (*args))]
-    pub fn new(args: &PyTuple) -> PyResult<Self> {
-        match args.len() {
-            // Create dummy inner PhysicalPlan, to be overridden by __setstate__.
-            0 => Ok(Arc::new(PhysicalPlan::InMemoryScan(InMemoryScan::new(
-                Default::default(),
-                InMemoryInfo::new(
-                    daft_core::schema::Schema::new(vec![])?.into(),
-                    "".to_string(),
-                    args.py().None(),
-                ),
-                Default::default(),
-            )))
-            .into()),
-            _ => Err(PyValueError::new_err(format!(
-                "expected no arguments to make new PhysicalPlanScheduler, got : {}",
-                args.len()
-            ))),
-        }
-    }
-
-    pub fn to_partition_tasks(&self, psets: HashMap<String, Vec<PyObject>>) -> PyResult<PyObject> {
-        Python::with_gil(|py| self.plan.to_partition_tasks(py, &psets))
+    /// Converts the contained physical plan into an iterator of executable partition tasks.
+    pub fn to_partition_tasks(
+        &self,
+        psets: HashMap<String, Vec<PyObject>>,
+        is_ray_runner: bool,
+    ) -> PyResult<PyObject> {
+        Python::with_gil(|py| self.plan.to_partition_tasks(py, &psets, is_ray_runner))
     }
 }
 
@@ -118,13 +102,16 @@ impl PartitionIterator {
 }
 
 #[cfg(feature = "python")]
+#[allow(clippy::too_many_arguments)]
 fn tabular_scan(
     py: Python<'_>,
     source_schema: &SchemaRef,
     projection_schema: &SchemaRef,
     file_infos: &Arc<FileInfos>,
     file_format_config: &Arc<FileFormatConfig>,
+    storage_config: &Arc<StorageConfig>,
     limit: &Option<usize>,
+    is_ray_runner: bool,
 ) -> PyResult<PyObject> {
     let columns_to_read = projection_schema
         .fields
@@ -140,7 +127,9 @@ fn tabular_scan(
             columns_to_read,
             file_infos.to_table()?,
             PyFileFormatConfig::from(file_format_config.clone()),
+            PyStorageConfig::from(storage_config.clone()),
             *limit,
+            is_ray_runner,
         ))?;
     Ok(py_iter.into())
 }
@@ -180,6 +169,7 @@ impl PhysicalPlan {
         &self,
         py: Python<'_>,
         psets: &HashMap<String, Vec<PyObject>>,
+        is_ray_runner: bool,
     ) -> PyResult<PyObject> {
         match self {
             PhysicalPlan::InMemoryScan(InMemoryScan {
@@ -203,6 +193,7 @@ impl PhysicalPlan {
                         source_schema,
                         file_infos,
                         file_format_config,
+                        storage_config,
                         ..
                     },
                 limit,
@@ -213,7 +204,9 @@ impl PhysicalPlan {
                 projection_schema,
                 file_infos,
                 file_format_config,
+                storage_config,
                 limit,
+                is_ray_runner,
             ),
             PhysicalPlan::TabularScanCsv(TabularScanCsv {
                 projection_schema,
@@ -222,6 +215,7 @@ impl PhysicalPlan {
                         source_schema,
                         file_infos,
                         file_format_config,
+                        storage_config,
                         ..
                     },
                 limit,
@@ -232,7 +226,9 @@ impl PhysicalPlan {
                 projection_schema,
                 file_infos,
                 file_format_config,
+                storage_config,
                 limit,
+                is_ray_runner,
             ),
             PhysicalPlan::TabularScanJson(TabularScanJson {
                 projection_schema,
@@ -241,6 +237,7 @@ impl PhysicalPlan {
                         source_schema,
                         file_infos,
                         file_format_config,
+                        storage_config,
                         ..
                     },
                 limit,
@@ -251,14 +248,16 @@ impl PhysicalPlan {
                 projection_schema,
                 file_infos,
                 file_format_config,
+                storage_config,
                 limit,
+                is_ray_runner,
             ),
             PhysicalPlan::Project(Project {
                 input,
                 projection,
                 resource_request,
             }) => {
-                let upstream_iter = input.to_partition_tasks(py, psets)?;
+                let upstream_iter = input.to_partition_tasks(py, psets, is_ray_runner)?;
                 let projection_pyexprs: Vec<PyExpr> = projection
                     .iter()
                     .map(|expr| PyExpr::from(expr.clone()))
@@ -270,7 +269,7 @@ impl PhysicalPlan {
                 Ok(py_iter.into())
             }
             PhysicalPlan::Filter(Filter { input, predicate }) => {
-                let upstream_iter = input.to_partition_tasks(py, psets)?;
+                let upstream_iter = input.to_partition_tasks(py, psets, is_ray_runner)?;
                 let expressions_mod =
                     py.import(pyo3::intern!(py, "daft.expressions.expressions"))?;
                 let py_predicate = expressions_mod
@@ -299,7 +298,7 @@ impl PhysicalPlan {
                 limit,
                 num_partitions,
             }) => {
-                let upstream_iter = input.to_partition_tasks(py, psets)?;
+                let upstream_iter = input.to_partition_tasks(py, psets, is_ray_runner)?;
                 let py_physical_plan =
                     py.import(pyo3::intern!(py, "daft.execution.physical_plan"))?;
                 let local_limit_iter = py_physical_plan
@@ -311,7 +310,7 @@ impl PhysicalPlan {
                 Ok(global_limit_iter.into())
             }
             PhysicalPlan::Explode(Explode { input, to_explode }) => {
-                let upstream_iter = input.to_partition_tasks(py, psets)?;
+                let upstream_iter = input.to_partition_tasks(py, psets, is_ray_runner)?;
                 let explode_pyexprs: Vec<PyExpr> = to_explode
                     .iter()
                     .map(|expr| PyExpr::from(expr.clone()))
@@ -328,7 +327,7 @@ impl PhysicalPlan {
                 descending,
                 num_partitions,
             }) => {
-                let upstream_iter = input.to_partition_tasks(py, psets)?;
+                let upstream_iter = input.to_partition_tasks(py, psets, is_ray_runner)?;
                 let sort_by_pyexprs: Vec<PyExpr> = sort_by
                     .iter()
                     .map(|expr| PyExpr::from(expr.clone()))
@@ -349,7 +348,7 @@ impl PhysicalPlan {
                 input_num_partitions,
                 output_num_partitions,
             }) => {
-                let upstream_iter = input.to_partition_tasks(py, psets)?;
+                let upstream_iter = input.to_partition_tasks(py, psets, is_ray_runner)?;
                 let py_iter = py
                     .import(pyo3::intern!(py, "daft.execution.physical_plan"))?
                     .getattr(pyo3::intern!(py, "split"))?
@@ -357,7 +356,7 @@ impl PhysicalPlan {
                 Ok(py_iter.into())
             }
             PhysicalPlan::Flatten(Flatten { input }) => {
-                let upstream_iter = input.to_partition_tasks(py, psets)?;
+                let upstream_iter = input.to_partition_tasks(py, psets, is_ray_runner)?;
                 let py_iter = py
                     .import(pyo3::intern!(py, "daft.execution.physical_plan"))?
                     .getattr(pyo3::intern!(py, "flatten_plan"))?
@@ -368,7 +367,7 @@ impl PhysicalPlan {
                 input,
                 num_partitions,
             }) => {
-                let upstream_iter = input.to_partition_tasks(py, psets)?;
+                let upstream_iter = input.to_partition_tasks(py, psets, is_ray_runner)?;
                 let py_iter = py
                     .import(pyo3::intern!(py, "daft.execution.physical_plan"))?
                     .getattr(pyo3::intern!(py, "fanout_random"))?
@@ -380,7 +379,7 @@ impl PhysicalPlan {
                 num_partitions,
                 partition_by,
             }) => {
-                let upstream_iter = input.to_partition_tasks(py, psets)?;
+                let upstream_iter = input.to_partition_tasks(py, psets, is_ray_runner)?;
                 let partition_by_pyexprs: Vec<PyExpr> = partition_by
                     .iter()
                     .map(|expr| PyExpr::from(expr.clone()))
@@ -395,7 +394,7 @@ impl PhysicalPlan {
                 "FanoutByRange not implemented, since only use case (sorting) doesn't need it yet."
             ),
             PhysicalPlan::ReduceMerge(ReduceMerge { input }) => {
-                let upstream_iter = input.to_partition_tasks(py, psets)?;
+                let upstream_iter = input.to_partition_tasks(py, psets, is_ray_runner)?;
                 let py_iter = py
                     .import(pyo3::intern!(py, "daft.execution.rust_physical_plan_shim"))?
                     .getattr(pyo3::intern!(py, "reduce_merge"))?
@@ -408,7 +407,7 @@ impl PhysicalPlan {
                 input,
                 ..
             }) => {
-                let upstream_iter = input.to_partition_tasks(py, psets)?;
+                let upstream_iter = input.to_partition_tasks(py, psets, is_ray_runner)?;
                 let aggs_as_pyexprs: Vec<PyExpr> = aggregations
                     .iter()
                     .map(|agg_expr| PyExpr::from(Expr::Agg(agg_expr.clone())))
@@ -428,7 +427,7 @@ impl PhysicalPlan {
                 num_from,
                 num_to,
             }) => {
-                let upstream_iter = input.to_partition_tasks(py, psets)?;
+                let upstream_iter = input.to_partition_tasks(py, psets, is_ray_runner)?;
                 let py_iter = py
                     .import(pyo3::intern!(py, "daft.execution.physical_plan"))?
                     .getattr(pyo3::intern!(py, "coalesce"))?
@@ -436,8 +435,8 @@ impl PhysicalPlan {
                 Ok(py_iter.into())
             }
             PhysicalPlan::Concat(Concat { other, input }) => {
-                let upstream_input_iter = input.to_partition_tasks(py, psets)?;
-                let upstream_other_iter = other.to_partition_tasks(py, psets)?;
+                let upstream_input_iter = input.to_partition_tasks(py, psets, is_ray_runner)?;
+                let upstream_other_iter = other.to_partition_tasks(py, psets, is_ray_runner)?;
                 let py_iter = py
                     .import(pyo3::intern!(py, "daft.execution.physical_plan"))?
                     .getattr(pyo3::intern!(py, "concat"))?
@@ -452,8 +451,8 @@ impl PhysicalPlan {
                 join_type,
                 ..
             }) => {
-                let upstream_left_iter = left.to_partition_tasks(py, psets)?;
-                let upstream_right_iter = right.to_partition_tasks(py, psets)?;
+                let upstream_left_iter = left.to_partition_tasks(py, psets, is_ray_runner)?;
+                let upstream_right_iter = right.to_partition_tasks(py, psets, is_ray_runner)?;
                 let left_on_pyexprs: Vec<PyExpr> = left_on
                     .iter()
                     .map(|expr| PyExpr::from(expr.clone()))
@@ -486,7 +485,7 @@ impl PhysicalPlan {
                 input,
             }) => tabular_write(
                 py,
-                input.to_partition_tasks(py, psets)?,
+                input.to_partition_tasks(py, psets, is_ray_runner)?,
                 file_format,
                 schema,
                 root_dir,
@@ -505,7 +504,7 @@ impl PhysicalPlan {
                 input,
             }) => tabular_write(
                 py,
-                input.to_partition_tasks(py, psets)?,
+                input.to_partition_tasks(py, psets, is_ray_runner)?,
                 file_format,
                 schema,
                 root_dir,
@@ -524,7 +523,7 @@ impl PhysicalPlan {
                 input,
             }) => tabular_write(
                 py,
-                input.to_partition_tasks(py, psets)?,
+                input.to_partition_tasks(py, psets, is_ray_runner)?,
                 file_format,
                 schema,
                 root_dir,
