@@ -5,13 +5,13 @@ use common_error::DaftResult;
 use daft_core::count_mode::CountMode;
 use daft_dsl::Expr;
 
-use crate::logical_plan::LogicalPlan;
-use crate::ops::{
+use crate::logical_ops::{
     Aggregate as LogicalAggregate, Coalesce as LogicalCoalesce, Concat as LogicalConcat,
     Distinct as LogicalDistinct, Explode as LogicalExplode, Filter as LogicalFilter,
     Join as LogicalJoin, Limit as LogicalLimit, Project as LogicalProject,
     Repartition as LogicalRepartition, Sink as LogicalSink, Sort as LogicalSort, Source,
 };
+use crate::logical_plan::LogicalPlan;
 use crate::physical_plan::PhysicalPlan;
 use crate::sink_info::{OutputFileInfo, SinkInfo};
 use crate::source_info::{ExternalInfo as ExternalSourceInfo, FileFormatConfig, SourceInfo};
@@ -21,6 +21,7 @@ use crate::{FileFormat, PartitionScheme};
 #[cfg(feature = "python")]
 use crate::physical_ops::InMemoryScan;
 
+/// Translate a logical plan to a physical plan.
 pub fn plan(logical_plan: &LogicalPlan) -> DaftResult<PhysicalPlan> {
     match logical_plan {
         LogicalPlan::Source(Source {
@@ -170,7 +171,7 @@ pub fn plan(logical_plan: &LogicalPlan) -> DaftResult<PhysicalPlan> {
             let input_physical = plan(input)?;
             Ok(PhysicalPlan::Coalesce(Coalesce::new(
                 input_physical.into(),
-                logical_plan.partition_spec().num_partitions,
+                input.partition_spec().num_partitions,
                 *num_to,
             )))
         }
