@@ -4,7 +4,6 @@ import pytest
 
 import daft
 from daft.datatype import DataType
-from daft.logical.logical_plan import LogicalPlan
 
 
 @pytest.fixture(scope="function")
@@ -12,10 +11,6 @@ def df():
     return daft.from_pydict({"foo": [1, 2, 3]})
 
 
-def test_get_plan(df):
-    assert isinstance(df.plan(), LogicalPlan)
-
-
 def test_num_partitions(df):
     assert df.num_partitions() == 1
 
