@@ -78,6 +78,28 @@ def retry_server_s3_config(request) -> daft.io.IOConfig:
 ###
 
 
+@contextlib.contextmanager
+def minio_create_bucket(
+    minio_io_config: daft.io.IOConfig, bucket_name: str = "my-minio-bucket"
+) -> YieldFixture[list[str]]:
+    """Creates a bucket in MinIO
+
+    Yields a s3fs FileSystem
+    """
+    fs = s3fs.S3FileSystem(
+        key=minio_io_config.s3.key_id,
+        password=minio_io_config.s3.access_key,
+        client_kwargs={"endpoint_url": minio_io_config.s3.endpoint_url},
+    )
+    if fs.exists(bucket_name):
+        fs.rm(bucket_name, recursive=True)
+    fs.mkdir(bucket_name)
+    try:
+        yield fs
+    finally:
+        fs.rm(bucket_name, recursive=True)
+
+
 @contextlib.contextmanager
 def mount_data_minio(
     minio_io_config: daft.io.IOConfig, folder: pathlib.Path, bucket_name: str = "my-minio-bucket"
@@ -86,26 +108,17 @@ def mount_data_minio(
 
     Yields a list of S3 URLs
     """
-    fs = s3fs.S3FileSystem(
-        key=minio_io_config.s3.key_id,
-        password=minio_io_config.s3.access_key,
-        client_kwargs={"endpoint_url": minio_io_config.s3.endpoint_url},
-    )
-    fs.mkdir(bucket_name)
+    with minio_create_bucket(minio_io_config=minio_io_config, bucket_name=bucket_name) as fs:
+        urls = []
+        for p in folder.glob("**/*"):
+            if not p.is_file():
+                continue
+            key = str(p.relative_to(folder))
+            url = f"s3://{bucket_name}/{key}"
+            fs.write_bytes(url, p.read_bytes())
+            urls.append(url)
 
-    urls = []
-    for p in folder.glob("**/*"):
-        if not p.is_file():
-            continue
-        key = str(p.relative_to(folder))
-        url = f"s3://{bucket_name}/{key}"
-        fs.write_bytes(url, p.read_bytes())
-        urls.append(url)
-
-    try:
         yield urls
-    finally:
-        fs.rm(bucket_name, recursive=True)
 
 
 @contextlib.contextmanager
