@@ -132,14 +132,14 @@ def test_series_cast_python_to_list(dtype) -> None:
     data = [[1, 2, 3], np.arange(3), ["1", "2", "3"], [1, "2", 3.0], pd.Series([1.1, 2]), (1, 2), None]
     s = Series.from_pylist(data, pyobj="force")
 
-    target_dtype = DataType.list("arr", DataType.from_arrow_type(dtype))
+    target_dtype = DataType.list(DataType.from_arrow_type(dtype))
 
     t = s.cast(target_dtype)
 
     assert t.datatype() == target_dtype
     assert len(t) == len(data)
 
-    assert t.arr.lengths().to_pylist() == [3, 3, 3, 3, 2, 2, None]
+    assert t.list.lengths().to_pylist() == [3, 3, 3, 3, 2, 2, None]
 
     pydata = t.to_pylist()
     assert pydata[-1] is None
@@ -153,14 +153,14 @@ def test_series_cast_python_to_fixed_size_list(dtype) -> None:
     data = [[1, 2, 3], np.arange(3), ["1", "2", "3"], [1, "2", 3.0], pd.Series([1.1, 2, 3]), (1, 2, 3), None]
     s = Series.from_pylist(data, pyobj="force")
 
-    target_dtype = DataType.fixed_size_list("arr", DataType.from_arrow_type(dtype), 3)
+    target_dtype = DataType.fixed_size_list(DataType.from_arrow_type(dtype), 3)
 
     t = s.cast(target_dtype)
 
     assert t.datatype() == target_dtype
     assert len(t) == len(data)
 
-    assert t.arr.lengths().to_pylist() == [3, 3, 3, 3, 3, 3, None]
+    assert t.list.lengths().to_pylist() == [3, 3, 3, 3, 3, 3, None]
 
     pydata = t.to_pylist()
     assert pydata[-1] is None
@@ -174,14 +174,14 @@ def test_series_cast_python_to_embedding(dtype) -> None:
     data = [[1, 2, 3], np.arange(3), ["1", "2", "3"], [1, "2", 3.0], pd.Series([1.1, 2, 3]), (1, 2, 3), None]
     s = Series.from_pylist(data, pyobj="force")
 
-    target_dtype = DataType.embedding("arr", DataType.from_arrow_type(dtype), 3)
+    target_dtype = DataType.embedding(DataType.from_arrow_type(dtype), 3)
 
     t = s.cast(target_dtype)
 
     assert t.datatype() == target_dtype
     assert len(t) == len(data)
 
-    assert t.arr.lengths().to_pylist() == [3, 3, 3, 3, 3, 3, None]
+    assert t.list.lengths().to_pylist() == [3, 3, 3, 3, 3, 3, None]
 
     pydata = t.to_pylist()
     assert pydata[-1] is None
@@ -190,7 +190,7 @@ def test_series_cast_python_to_embedding(dtype) -> None:
 
 def test_series_cast_numpy_to_image() -> None:
     data = [
-        np.arange(12, dtype=np.uint8).reshape((3, 2, 2)),
+        np.arange(12, dtype=np.uint8).reshape((2, 2, 3)),
         np.arange(12, 39, dtype=np.uint8).reshape((3, 3, 3)),
         None,
     ]
@@ -203,7 +203,7 @@ def test_series_cast_numpy_to_image() -> None:
     assert t.datatype() == target_dtype
     assert len(t) == len(data)
 
-    assert t.arr.lengths().to_pylist() == [12, 27, None]
+    assert t.list.lengths().to_pylist() == [12, 27, None]
 
     pydata = t.to_pylist()
     assert pydata[-1] is None
@@ -221,7 +221,7 @@ def test_series_cast_numpy_to_image_infer_mode() -> None:
     assert t.datatype() == target_dtype
     assert len(t) == len(data)
 
-    assert t.arr.lengths().to_pylist() == [4, 27, None]
+    assert t.list.lengths().to_pylist() == [4, 27, None]
 
     pydata = t.to_arrow().to_pylist()
     assert pydata[0] == {"data": data[0].ravel().tolist(), "mode": ImageMode.L, "channel": 1, "height": 2, "width": 2}
@@ -236,7 +236,7 @@ def test_series_cast_python_to_fixed_shape_image() -> None:
     height = 2
     width = 2
     shape = (height, width, 3)
-    data = [np.arange(12).reshape(shape), np.arange(12, 24).reshape(shape), None]
+    data = [np.arange(12, dtype=np.uint8).reshape(shape), np.arange(12, 24, dtype=np.uint8).reshape(shape), None]
     s = Series.from_pylist(data, pyobj="force")
 
     target_dtype = DataType.image("RGB", height, width)
@@ -246,13 +246,276 @@ def test_series_cast_python_to_fixed_shape_image() -> None:
     assert t.datatype() == target_dtype
     assert len(t) == len(data)
 
-    assert t.arr.lengths().to_pylist() == [12, 12, None]
+    assert t.list.lengths().to_pylist() == [12, 12, None]
 
     pydata = t.to_pylist()
     assert pydata[-1] is None
     np.testing.assert_equal(data[:-1], pydata[:-1])
 
 
+def test_series_cast_numpy_to_tensor() -> None:
+    data = [
+        np.arange(12, dtype=np.uint8).reshape((2, 2, 3)),
+        np.arange(12, 39, dtype=np.uint8).reshape((3, 3, 3)),
+        None,
+    ]
+    s = Series.from_pylist(data, pyobj="force")
+
+    target_dtype = DataType.tensor(DataType.uint8())
+
+    t = s.cast(target_dtype)
+
+    assert t.datatype() == target_dtype
+    assert len(t) == len(data)
+
+    pydata = t.to_pylist()
+    assert pydata[-1] is None
+    np.testing.assert_equal(data[:-1], pydata[:-1])
+
+
+def test_series_cast_numpy_to_fixed_shape_tensor() -> None:
+    shape = (2, 2)
+    data = [
+        np.arange(4, dtype=np.uint8).reshape(shape),
+        np.arange(4, 8, dtype=np.uint8).reshape(shape),
+        None,
+    ]
+    s = Series.from_pylist(data, pyobj="force")
+
+    target_dtype = DataType.tensor(DataType.uint8(), shape)
+
+    t = s.cast(target_dtype)
+
+    assert t.datatype() == target_dtype
+    assert len(t) == len(data)
+
+    pydata = t.to_pylist()
+    assert pydata[-1] is None
+    np.testing.assert_equal(data[:-1], pydata[:-1])
+
+
+def test_series_cast_image_to_fixed_shape_image() -> None:
+    height = 2
+    width = 2
+    shape = (height, width, 3)
+    data = [np.arange(12, dtype=np.uint8).reshape(shape), np.arange(12, 24, dtype=np.uint8).reshape(shape), None]
+    s = Series.from_pylist(data, pyobj="force")
+
+    target_dtype = DataType.image("RGB")
+
+    t = s.cast(target_dtype)
+
+    assert t.datatype() == target_dtype
+
+    target_dtype = DataType.image("RGB", height, width)
+    u = t.cast(target_dtype)
+
+    assert u.datatype() == target_dtype
+    assert len(u) == len(data)
+
+    pydata = u.to_pylist()
+    assert pydata[-1] is None
+    np.testing.assert_equal(pydata[:-1], data[:-1])
+
+
+def test_series_cast_image_to_tensor() -> None:
+    data = [
+        np.arange(12, dtype=np.uint8).reshape((2, 2, 3)),
+        np.arange(12, 39, dtype=np.uint8).reshape((3, 3, 3)),
+        None,
+    ]
+    s = Series.from_pylist(data, pyobj="force")
+
+    target_dtype = DataType.image("RGB")
+
+    t = s.cast(target_dtype)
+
+    assert t.datatype() == target_dtype
+
+    target_dtype = DataType.tensor(DataType.uint8())
+
+    u = t.cast(target_dtype)
+
+    assert u.datatype() == target_dtype
+    assert len(u) == len(data)
+
+    pydata = u.to_pylist()
+    assert pydata[-1] is None
+    np.testing.assert_equal(data[:-1], pydata[:-1])
+
+
+def test_series_cast_image_to_fixed_shape_tensor() -> None:
+    height = 2
+    width = 2
+    shape = (height, width, 3)
+    data = [np.arange(12, dtype=np.uint8).reshape(shape), np.arange(12, 24, dtype=np.uint8).reshape(shape), None]
+    s = Series.from_pylist(data, pyobj="force")
+
+    target_dtype = DataType.image("RGB")
+
+    t = s.cast(target_dtype)
+
+    assert t.datatype() == target_dtype
+
+    target_dtype = DataType.tensor(DataType.uint8(), shape)
+    u = t.cast(target_dtype)
+
+    assert u.datatype() == target_dtype
+    assert len(u) == len(data)
+
+    pydata = u.to_pylist()
+    assert pydata[-1] is None
+    np.testing.assert_equal(pydata[:-1], data[:-1])
+
+
+def test_series_cast_fixed_shape_image_to_image() -> None:
+    height = 2
+    width = 2
+    shape = (height, width, 3)
+    data = [np.arange(12, dtype=np.uint8).reshape(shape), np.arange(12, 24, dtype=np.uint8).reshape(shape), None]
+    s = Series.from_pylist(data, pyobj="force")
+
+    target_dtype = DataType.image("RGB", height, width)
+
+    t = s.cast(target_dtype)
+
+    assert t.datatype() == target_dtype
+
+    target_dtype = DataType.image("RGB")
+    u = t.cast(target_dtype)
+
+    assert u.datatype() == target_dtype
+    assert len(u) == len(data)
+
+    pydata = u.to_pylist()
+    assert pydata[-1] is None
+    np.testing.assert_equal(pydata[:-1], data[:-1])
+
+
+def test_series_cast_fixed_shape_image_to_fixed_shape_tensor() -> None:
+    height = 2
+    width = 2
+    shape = (height, width, 3)
+    data = [np.arange(12, dtype=np.uint8).reshape(shape), np.arange(12, 24, dtype=np.uint8).reshape(shape), None]
+    s = Series.from_pylist(data, pyobj="force")
+
+    target_dtype = DataType.image("RGB", height, width)
+
+    t = s.cast(target_dtype)
+
+    assert t.datatype() == target_dtype
+
+    target_dtype = DataType.tensor(DataType.uint8(), shape)
+    u = t.cast(target_dtype)
+
+    assert u.datatype() == target_dtype
+    assert len(u) == len(data)
+
+    pydata = u.to_pylist()
+    assert pydata[-1] is None
+    np.testing.assert_equal(pydata[:-1], data[:-1])
+
+
+def test_series_cast_fixed_shape_image_to_tensor() -> None:
+    height = 2
+    width = 2
+    shape = (height, width, 3)
+    data = [np.arange(12, dtype=np.uint8).reshape(shape), np.arange(12, 24, dtype=np.uint8).reshape(shape), None]
+    s = Series.from_pylist(data, pyobj="force")
+
+    target_dtype = DataType.image("RGB", height, width)
+
+    t = s.cast(target_dtype)
+
+    assert t.datatype() == target_dtype
+
+    target_dtype = DataType.tensor(DataType.uint8())
+    u = t.cast(target_dtype)
+
+    assert u.datatype() == target_dtype
+    assert len(u) == len(data)
+
+    pydata = u.to_pylist()
+    assert pydata[-1] is None
+    np.testing.assert_equal(pydata[:-1], data[:-1])
+
+
+def test_series_cast_fixed_shape_tensor_to_tensor() -> None:
+    shape = (2, 2, 3)
+    data = [np.arange(12, dtype=np.uint8).reshape(shape), np.arange(12, 24, dtype=np.uint8).reshape(shape), None]
+    s = Series.from_pylist(data, pyobj="force")
+
+    target_dtype = DataType.tensor(DataType.uint8(), shape)
+
+    t = s.cast(target_dtype)
+
+    assert t.datatype() == target_dtype
+
+    target_dtype = DataType.tensor(DataType.uint8())
+    u = t.cast(target_dtype)
+
+    assert u.datatype() == target_dtype
+    assert len(u) == len(data)
+
+    pydata = u.to_pylist()
+    assert pydata[-1] is None
+    np.testing.assert_equal(pydata[:-1], data[:-1])
+
+
+def test_series_cast_embedding_to_fixed_shape_tensor() -> None:
+    shape = (4,)
+    data = [
+        np.arange(4, dtype=np.uint8).reshape(shape),
+        np.arange(4, 8, dtype=np.uint8).reshape(shape),
+        None,
+    ]
+    s = Series.from_pylist(data, pyobj="force")
+
+    target_dtype = DataType.embedding(DataType.uint8(), 4)
+
+    t = s.cast(target_dtype)
+
+    assert t.datatype() == target_dtype
+
+    target_dtype = DataType.tensor(DataType.uint8(), shape)
+
+    u = t.cast(target_dtype)
+
+    assert u.datatype() == target_dtype
+    assert len(u) == len(data)
+
+    pydata = u.to_pylist()
+    assert pydata[-1] is None
+    np.testing.assert_equal(data[:-1], pydata[:-1])
+
+
+def test_series_cast_embedding_to_tensor() -> None:
+    shape = (4,)
+    data = [
+        np.arange(4, dtype=np.uint8).reshape(shape),
+        np.arange(4, 8, dtype=np.uint8).reshape(shape),
+        None,
+    ]
+    s = Series.from_pylist(data, pyobj="force")
+
+    target_dtype = DataType.embedding(DataType.uint8(), 4)
+
+    t = s.cast(target_dtype)
+
+    assert t.datatype() == target_dtype
+
+    target_dtype = DataType.tensor(DataType.uint8())
+
+    u = t.cast(target_dtype)
+
+    assert u.datatype() == target_dtype
+    assert len(u) == len(data)
+
+    pydata = u.to_pylist()
+    assert pydata[-1] is None
+    np.testing.assert_equal(data[:-1], pydata[:-1])
+
+
 @pytest.mark.parametrize(
     "timeunit",
     [
@@ -464,3 +727,36 @@ def test_series_cast_logical_numeric(dtype, result_n1, result_0, result_p1) -> N
     series = Series.from_pylist([result_n1, result_0, result_p1]).cast(dtype)
     casted = series.cast(DataType.int64())
     assert casted.to_pylist() == [-1, 0, 1]
+
+
+def test_series_cast_struct_col_reordering() -> None:
+    data = pa.array([{"foo": i, "bar": i} for i in range(10)], type=pa.struct({"foo": pa.int64(), "bar": pa.int64()}))
+    series = Series.from_arrow(data)
+    assert series.datatype() == DataType.struct({"foo": DataType.int64(), "bar": DataType.int64()})
+
+    cast_to = DataType.struct({"bar": DataType.int32(), "foo": DataType.int32()})
+    casted = series.cast(cast_to)
+    assert casted.datatype() == cast_to
+    assert casted.to_pylist() == data.to_pylist()
+
+
+def test_series_cast_struct_prune_col() -> None:
+    data = pa.array([{"foo": i, "bar": i} for i in range(10)], type=pa.struct({"foo": pa.int64(), "bar": pa.int64()}))
+    series = Series.from_arrow(data)
+    assert series.datatype() == DataType.struct({"foo": DataType.int64(), "bar": DataType.int64()})
+
+    cast_to = DataType.struct({"bar": DataType.int32()})
+    casted = series.cast(cast_to)
+    assert casted.datatype() == cast_to
+    assert casted.to_pylist() == [{"bar": x["bar"]} for x in data.to_pylist()]
+
+
+def test_series_cast_struct_add_col() -> None:
+    data = pa.array([{"foo": i, "bar": i} for i in range(10)], type=pa.struct({"foo": pa.int64(), "bar": pa.int64()}))
+    series = Series.from_arrow(data)
+    assert series.datatype() == DataType.struct({"foo": DataType.int64(), "bar": DataType.int64()})
+
+    cast_to = DataType.struct({"bar": DataType.int32(), "foo": DataType.int32(), "baz": DataType.string()})
+    casted = series.cast(cast_to)
+    assert casted.datatype() == cast_to
+    assert casted.to_pylist() == [{**x, "baz": None} for x in data.to_pylist()]
