@@ -446,22 +446,22 @@ def test_logical_ops_with_non_boolean() -> None:
     l = Series.from_arrow(l_arrow)
     r = Series.from_arrow(r_arrow)
 
-    with pytest.raises(ValueError, match="logical operations on boolean supertype"):
+    with pytest.raises(ValueError, match="logic"):
         l & r
 
-    with pytest.raises(ValueError, match="logical operations on boolean supertype"):
+    with pytest.raises(ValueError, match="logic"):
         l | r
 
-    with pytest.raises(ValueError, match="logical operations on boolean supertype"):
+    with pytest.raises(ValueError, match="logic"):
         l ^ r
 
-    with pytest.raises(ValueError, match="logical operations on boolean supertype"):
+    with pytest.raises(ValueError, match="logic"):
         r & l
 
-    with pytest.raises(ValueError, match="logical operations on boolean supertype"):
+    with pytest.raises(ValueError, match="logic"):
         r | l
 
-    with pytest.raises(ValueError, match="logical operations on boolean supertype"):
+    with pytest.raises(ValueError, match="logic"):
         r ^ l
 
 
